﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Infragistics.Silverlight.Timeline;
using Infragistics.Silverlight.Controls;

namespace SilverlightApplication35
{
    public partial class MainPage : UserControl
    {
        TimelineEntity timeLineEntity = null;

        DateTimeAxis axis = null;
        public MainPage()
        {
            InitializeComponent();
            LoadData();
            axis = new DateTimeAxis()
            {
                Minimum = timeLineEntity.StartTime,
                Maximum = timeLineEntity.EndTime,
                AutoRange = true,
                Unit = 2,
                UnitType = DateTimeUnitType.Seconds,
                ShowLabels = false,
                ShowMinorGridLines = false,
                ShowMajorTickMarks = false,
                ShowLabelsInPreview = false,
                ShowMinorTickMarks = false,
                ShowThumb = false
            };

            int i = 0;
            StackPanel timeLineStack = new StackPanel();
            foreach (Events eventItem in timeLineEntity.EventList)
            {
                XamWebTimeline timeline1 = new XamWebTimeline();
                DateTimeSeries timeSeries = new DateTimeSeries();
                DateTimeAxis subaxis = new DateTimeAxis()
                {
                    Minimum = eventItem.StartTime,
                    Maximum = eventItem.EndTime,
                    AutoRange = true,
                    Unit = 2,
                    UnitType = DateTimeUnitType.Seconds,
                    ShowLabels = false,
                    ShowMinorGridLines = false,
                    ShowMajorTickMarks = false,
                    ShowLabelsInPreview = false,
                    ShowMinorTickMarks = false,
                    ShowThumb = false
                };
                timeline1.Axis = subaxis;

                foreach (DateTime marker in eventItem.Markers)
                {
                    DateTimeEntry entry = new DateTimeEntry();
                    entry.Time = eventItem.Markers[0];

                    entry.Title = "Marker in Event";
                    entry.Details = "";

                    timeSeries.Entries.Add(entry);
                }

                timeline1.Series.Add(timeSeries);

                i++;

                timeline1.VerticalContentAlignment = VerticalAlignment.Top;

                timeLineStack.Children.Add(timeline1);
            }
            this.LayoutRoot.Children.Add(timeLineStack);
        }
        private void LoadData()
        {
            timeLineEntity = new TimelineEntity();
            timeLineEntity.StartTime = Convert.ToDateTime("08/01/2009 12:00:00");
            timeLineEntity.EndTime = Convert.ToDateTime("08/11/2009 13:30:00");
            timeLineEntity.Title = "Event Time Line";
            string[] startDate = new string[5];
            startDate[0] = "08/01/2009 12:00:00";
            startDate[1] = "08/01/2009 12:10:00";
            startDate[2] = "08/04/2009 13:30:00";
            startDate[3] = "08/06/2009 06:30:00";
            startDate[4] = "08/08/2009 04:30:00";
            string[] endDate = new string[5];
            endDate[0] = "08/02/2009 13:30:00";
            endDate[1] = "08/04/2009 10:30:00";
            endDate[2] = "08/04/2009 13:40:00";
            endDate[3] = "08/06/2009 07:30:00";
            endDate[4] = "08/08/2009 13:30:00";
            string[] markerstartDate = new string[5];
            markerstartDate[0] = "08/01/2009 13:30:00";
            markerstartDate[1] = "08/03/2009 13:30:00";
            markerstartDate[2] = "08/04/2009 13:35:00";
            markerstartDate[3] = "08/06/2009 06:40:00";
            markerstartDate[4] = "08/08/2009 07:00:10";
            List<Events> eventList = new List<Events>();
            for (int i = 0; i < 5; i++)
            {

                Events eventItem = new Events();
                eventItem.Title = "Event #" + (i + 1).ToString() + " Event Type";
                eventItem.StartTime = Convert.ToDateTime(startDate[i]);
                eventItem.EndTime = Convert.ToDateTime(endDate[i]);
                List<DateTime> markers = new List<DateTime>();
                markers.Add(Convert.ToDateTime(markerstartDate[i]));
                eventItem.Markers = markers;
                eventList.Add(eventItem);

            }
            timeLineEntity.EventList = eventList;
        }
        private void Zoombar_ZoomChanged(object sender, ZoomChangedEventArgs e)
        {
            List<XamWebTimeline> timelines = new List<XamWebTimeline>();
            this.GetTimelines(this.LayoutRoot.Children, timelines);
            foreach (XamWebTimeline timeline in timelines)
            {
                timeline.Axis.ScrollPosition = e.NewRange.Scroll;
                timeline.Axis.ScrollScale = e.NewRange.Scale;
            }
        }
        private void GetTimelines(UIElementCollection elements, List<XamWebTimeline> result)
        {
            foreach (UIElement ctrl in elements)
            {
                if (ctrl is XamWebTimeline)
                {
                    result.Add((XamWebTimeline)ctrl);
                }
                else if (ctrl is Panel)
                {
                    this.GetTimelines(((Panel)ctrl).Children, result);
                }
            }
        }


        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {
            List<XamWebTimeline> timelines = new List<XamWebTimeline>();
            this.GetTimelines(this.LayoutRoot.Children, timelines);
            foreach (XamWebTimeline timeline in timelines)
            {
                timeline.Background = new SolidColorBrush(Colors.White);
                if (timeline.Zoombar != null)
                {
                    timeline.Zoombar.Visibility = Visibility.Collapsed;
                }
                timeline.Axis.PaneStyle = (Style)this.Resources["PaneStyle1"];
                timeline.Axis.VerticalContentAlignment = VerticalAlignment.Top;
                timeline.LegendStyle = (Style)this.Resources["LegendStyle1"];

                timeline.SceneStyle = (Style)this.Resources["SceneStyle1"];

                foreach (DateTimeSeries series in timeline.Series)
                {

                    series.EventPointStyle = (Style)this.Resources["EventPointStyle1"];
                    series.EventTitleStyle = (Style)this.Resources["EventTitleStyle1"];
                    series.EventSpanStyle = (Style)this.Resources["EventSpan1Style"];
                }
            }

            Zoombar.Range.FromScaleScroll(axis.ScrollScale, axis.ScrollPosition);

        }
    }
    public class TimelineEntity
    {
        public string Title { get; set; }
        public DateTime StartTime { get; set; }
        public DateTime EndTime { get; set; }
        public List<Events> EventList { get; set; }
    }
    public class Events
    {
        public string Title { get; set; }
        public DateTime StartTime { get; set; }
        public DateTime EndTime { get; set; }
        public List<DateTime> Markers { get; set; }
    }
}
